//+------------------------------------------------------------------+
//|                                                    FiboPivot.mq4 |
//+------------------------------------------------------------------+
#property copyright ""
#property link      ""

#property indicator_chart_window

#define ARRAY_SIZE 7
#define NUM_BAR_BEGIN_DRAW 40 //  ,    

extern color ExtColorResist  = DarkTurquoise;
extern color ExtColorPivot   = Linen;
extern color ExtColorSupport = Tomato;
extern bool  ExtShowComment  = False;

string asNamesOfLine[  ARRAY_SIZE ] = { "R3", "R2", "R1", "PIV", "S1", "S2", "S3" };
string asNamesOfLabel[ ARRAY_SIZE ] = { "Res 3", "Res 2", "Res 1", 
                                        "Pivot", 
                                        "Sup 1", "Sup 2", "Sup 3" };

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
  return( 0 );
}

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
  for ( int iiObject = 0; iiObject < ARRAY_SIZE; iiObject++ ) {
    ObjectDelete( asNamesOfLine[  iiObject ] );
    ObjectDelete( asNamesOfLabel[ iiObject ] );
  }
  
  Comment( "" );
  
  return( 0 );
}

//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
int start()
{
  //double adRates[1][6];
  double dPrevClose;  //   
  double dPrevHigh;   //   
  double dPrevLow;    //    
  double dPrevRange;  //   
  double dPivotLevel; // Pivot
  double adLevels[ ARRAY_SIZE ]; //    
  
  /*ArrayCopyRates( adRates, Symbol(), PERIOD_D1 );
  
  if ( DayOfWeek() == 1 ) { //  : 
    if ( TimeDayOfWeek( iTime( Symbol(), PERIOD_D1, 1 ) ) == 5 ) { //  : 
      dPrevClose = adRates[1][4];
      dPrevHigh  = adRates[1][3];
      dPrevLow   = adRates[1][2];
    }
    else { //  :  
      for( int iiDay = 5; iiDay >= 0; iiDay-- ) { // ???  5-    
        if ( TimeDayOfWeek( iTime( Symbol(), PERIOD_D1, iiDay ) ) == 5 ) { //  
          dPrevClose = adRates[ iiDay ][4];
          dPrevHigh  = adRates[ iiDay ][3];
          dPrevLow   = adRates[ iiDay ][2];
        } // if
      } // for
    } // if
  } // if ( DayOfWeek() == 1 )
  
  else { //  :  - 
    dPrevClose = adRates[1][4];
    dPrevHigh  = adRates[1][3];
    dPrevLow   = adRates[1][2];
  } // if
  */
  dPrevClose = iClose( NULL, PERIOD_D1, 1 );
  dPrevHigh  = iHigh(  NULL, PERIOD_D1, 1 );
  dPrevLow   = iLow(   NULL, PERIOD_D1, 1 );
  //R1 = (iHigh(NULL,PERIOD_D1,1)-iLow(NULL,PERIOD_D1,1))/Point;
  
  //=== 
  //    
  dPrevRange  = dPrevHigh - dPrevLow;
  //    
  dPivotLevel = ( dPrevHigh + dPrevLow + dPrevClose )/3;
  
  adLevels[ 0 ] = dPivotLevel + ( dPrevRange * 1.000 );
  adLevels[ 1 ] = dPivotLevel + ( dPrevRange * 0.618 );
  adLevels[ 2 ] = dPivotLevel + ( dPrevRange * 0.382 );
  adLevels[ 3 ] = dPivotLevel;
  adLevels[ 4 ] = dPivotLevel - ( dPrevRange * 0.382 );
  adLevels[ 5 ] = dPivotLevel - ( dPrevRange * 0.618 );
  adLevels[ 6 ] = dPivotLevel - ( dPrevRange * 1.000 );
  
  for ( int iiObject = 0; iiObject < ARRAY_SIZE; iiObject++ )
    DrawGroup( adLevels[ iiObject ], 
               asNamesOfLine[ iiObject ], 
               asNamesOfLabel[ iiObject ] );
  
  if ( ExtShowComment )
    Comment( "PrHigh= ", dPrevHigh,
             " Prev Range= ", dPrevRange/Point,
             "\nPrLow= ", dPrevLow,
             " Cur Range= ", ( iHigh( NULL, PERIOD_D1, 0 ) - iLow( NULL, PERIOD_D1, 0 ) )/Point,
             "\nPrClose= ", dPrevClose );
           
  return ( 0 );
}

//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
void DrawGroup( double dObjectLevel, string sNameLine, string sNameLabel )
{
  DrawLine(  sNameLine , dObjectLevel );
  DrawLabel( sNameLabel, dObjectLevel );
} // void DrawGroup()

//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
void DrawLine( string sObjectName, double dObjectLevel )
{
  color cColor;
  
  cColor = SetColor( sObjectName );
  
  if ( ObjectFind( sObjectName ) == 0 ) {
    ObjectDelete( sObjectName );
  } // if
  
  ObjectCreate( sObjectName, OBJ_TREND, 0, 
                Time[ NUM_BAR_BEGIN_DRAW ], dObjectLevel, Time[0], dObjectLevel );
  ObjectSet( sObjectName, OBJPROP_STYLE, STYLE_DASHDOTDOT );
  ObjectSet( sObjectName, OBJPROP_COLOR, cColor );
  ObjectSet( sObjectName, OBJPROP_WIDTH, 1 );
  ObjectSet( sObjectName, OBJPROP_BACK , True );
  
} // void DrawLine()

//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
void DrawLabel( string sObjectName, double dObjectLevel )
{
  int iFirstVisibleBar = FirstVisibleBar();
  int iBarsPerWindow   = BarsPerWindow();
  double dTime;
  color  cColor;
  
  if ( iBarsPerWindow - iFirstVisibleBar > 2 ) //   
    dTime  = Time[0] + Period() * iBarsPerWindow * 9; //   ,   
    //   -     .  
  else //    
    dTime  = Time[ NUM_BAR_BEGIN_DRAW - 5 ]; //   ,   
  
  cColor = SetColor( sObjectName );
  
  if ( ObjectFind( sObjectName ) == 0 ) {
    ObjectDelete( sObjectName );
  } // if
  
  ObjectCreate( sObjectName, OBJ_TEXT, 0, dTime, dObjectLevel );
  ObjectSetText( sObjectName, 
                 sObjectName + " -> " + DoubleToStr( dObjectLevel, Digits ), 
                 8, "Arial", cColor );
  
} // void DrawLabel()

//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
color SetColor( string sObjectName )
{
  switch ( StringGetChar( sObjectName, 0 ) ) {
  case 'R': return( ExtColorResist  ); break;
  case 'P': return( ExtColorPivot   ); break;
  case 'S': return( ExtColorSupport ); break;
  }
  
} // color SetColor()

